@@ -17,6 +17,7 @@ names(ecospat.testNiche.nat)
 ## -----------------------------------------------------------------------------
 fpath <- system.file("extdata", "ecospat.testTree.tre", package="ecospat")
 fpath
+library(ape)
 tree<-read.tree(fpath)
 tree$tip.label
 
@@ -57,6 +58,7 @@ ecospat.plot.mess (mess.object, cex=1, pch=15)
 
 ## -----------------------------------------------------------------------------
 fpath <- system.file("extdata", "ecospat.testTree.tre", package="ecospat")
+library(ape)
 tree <- read.tree(fpath)
 data <- ecospat.testData[9:52]
 
@@ -76,6 +78,7 @@ inv <- ecospat.testNiche.inv
 nat <- ecospat.testNiche.nat
 
 ## -----------------------------------------------------------------------------
+library(ade4)
 pca.env <- dudi.pca(rbind(nat,inv)[,3:10],scannf=F,nf=2) 
 
 ## -----------------------------------------------------------------------------
@@ -117,15 +120,23 @@ D.overlap <- ecospat.niche.overlap (grid.clim.nat, grid.clim.inv, cor = TRUE)$D
 D.overlap
 
 ## -----------------------------------------------------------------------------
-eq.test <- ecospat.niche.equivalency.test(grid.clim.nat, grid.clim.inv,
-                                          rep=10, alternative = "greater")
+eq.test <- ecospat.niche.equivalency.test(grid.clim.nat, grid.clim.inv,rep=10,
+                                          intersection = 0.1,
+                                          overlap.alternative =  "higher",
+                                          expansion.alternative = "lower",
+                                          stability.alternative = "higher",
+                                          unfilling.alternative = "lower")
 
 ## -----------------------------------------------------------------------------
 ecospat.plot.overlap.test(eq.test, "D", "Equivalency")
 
 ## -----------------------------------------------------------------------------
-sim.test <- ecospat.niche.similarity.test(grid.clim.nat, grid.clim.inv,
-                                          rep=10, alternative = "greater",
+sim.test <- ecospat.niche.similarity.test(grid.clim.nat, grid.clim.inv,rep=10,
+                                          overlap.alternative =  "higher",
+                                          expansion.alternative = "lower",
+                                          stability.alternative = "higher",
+                                          unfilling.alternative = "lower",
+                                          intersection = 0.1,
                                           rand.type=2) 
 
 ## -----------------------------------------------------------------------------
@@ -141,6 +152,11 @@ ecospat.plot.niche.dyn(grid.clim.nat, grid.clim.inv, quant=0.25, interest=2,
 
 ecospat.shift.centroids(scores.sp.nat, scores.sp.inv, scores.clim.nat, scores.clim.inv)
 
+## -----------------------------------------------------------------------------
+ecospat.plot.overlap.test(sim.test, "expansion", "Similarity")
+ecospat.plot.overlap.test(sim.test, "stability", "Similarity")
+ecospat.plot.overlap.test(sim.test, "unfilling", "Similarity")
+
 ## -----------------------------------------------------------------------------
 # gridding the native niche
 grid.clim.t.nat <- ecospat.grid.clim.dyn(glob=as.data.frame(rbind(nat,inv)[,10]), 
@@ -191,7 +207,7 @@ obs<-ecospat.testData$glm_Saxifraga_oppositifolia[which(ecospat.testData$Saxifra
 
 ## ----boyce--------------------------------------------------------------------
 ecospat.boyce (fit, obs, nclass = 0, window.w = "default", res = 100, 
-               PEplot = TRUE)$Spearman.cor
+               PEplot = TRUE)$cor
 
 ## -----------------------------------------------------------------------------
 eval<-ecospat.testData[c(53,62,58,70,61,66,65,71,69,43,63,56,68,57,55,60,54,67,59,64)]
